==> dekorate-spring-boot-2.8.0-sources.jar: io/dekorate/spring/config/SpringApplicationConfigBuilder.java <==
package io.dekorate.spring.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class SpringApplicationConfigBuilder extends io.dekorate.spring.config.SpringApplicationConfigFluentImpl<io.dekorate.spring.config.SpringApplicationConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.dekorate.spring.config.SpringApplicationConfig,io.dekorate.spring.config.SpringApplicationConfigBuilder>{
  public SpringApplicationConfigBuilder() {
    this(false);
  }
  public SpringApplicationConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new SpringApplicationConfig(), validationEnabled);
  }
  public SpringApplicationConfigBuilder(io.dekorate.spring.config.SpringApplicationConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public SpringApplicationConfigBuilder(io.dekorate.spring.config.SpringApplicationConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SpringApplicationConfig(), validationEnabled);
  }
  public SpringApplicationConfigBuilder(io.dekorate.spring.config.SpringApplicationConfigFluent<?> fluent,io.dekorate.spring.config.SpringApplicationConfig instance) {
    this(fluent, instance, false);
  }
  public SpringApplicationConfigBuilder(io.dekorate.spring.config.SpringApplicationConfigFluent<?> fluent,io.dekorate.spring.config.SpringApplicationConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    this.validationEnabled = validationEnabled; 
  }
  public SpringApplicationConfigBuilder(io.dekorate.spring.config.SpringApplicationConfig instance) {
    this(instance,false);
  }
  public SpringApplicationConfigBuilder(io.dekorate.spring.config.SpringApplicationConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.spring.config.SpringApplicationConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.dekorate.spring.config.EditableSpringApplicationConfig build() {
    EditableSpringApplicationConfig buildable = new EditableSpringApplicationConfig();
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SpringApplicationConfigBuilder that = (SpringApplicationConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> dekorate-spring-boot-2.10.0-sources.jar: io/dekorate/spring/config/SpringApplicationConfigBuilder.java <==
package io.dekorate.spring.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class SpringApplicationConfigBuilder extends SpringApplicationConfigFluentImpl<SpringApplicationConfigBuilder> implements VisitableBuilder<io.dekorate.spring.config.SpringApplicationConfig,io.dekorate.spring.config.SpringApplicationConfigBuilder>{
  public SpringApplicationConfigBuilder() {
    this(false);
  }
  public SpringApplicationConfigBuilder(Boolean validationEnabled) {
    this(new SpringApplicationConfig(), validationEnabled);
  }
  public SpringApplicationConfigBuilder(SpringApplicationConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public SpringApplicationConfigBuilder(io.dekorate.spring.config.SpringApplicationConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SpringApplicationConfig(), validationEnabled);
  }
  public SpringApplicationConfigBuilder(io.dekorate.spring.config.SpringApplicationConfigFluent<?> fluent,io.dekorate.spring.config.SpringApplicationConfig instance) {
    this(fluent, instance, false);
  }
  public SpringApplicationConfigBuilder(io.dekorate.spring.config.SpringApplicationConfigFluent<?> fluent,io.dekorate.spring.config.SpringApplicationConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    this.validationEnabled = validationEnabled; 
  }
  public SpringApplicationConfigBuilder(io.dekorate.spring.config.SpringApplicationConfig instance) {
    this(instance,false);
  }
  public SpringApplicationConfigBuilder(io.dekorate.spring.config.SpringApplicationConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.spring.config.SpringApplicationConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public EditableSpringApplicationConfig build() {
    EditableSpringApplicationConfig buildable = new EditableSpringApplicationConfig();
    return buildable;
  }
  
}
